﻿using System.Collections.ObjectModel;
using System.Windows;
using System.ComponentModel;

namespace GridTest
{

	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window, INotifyPropertyChanged
	{
		public MainWindow()
		{
			CreateUiCollection(0);
			InitializeComponent();
		}

		public event PropertyChangedEventHandler PropertyChanged;
		void NotifyPropertyChanged(string propertyName)
		{
			PropertyChangedEventHandler handler = PropertyChanged;
			if (!object.ReferenceEquals(handler, null))
				handler(this, new PropertyChangedEventArgs(propertyName));
		}


		ObservableCollection<BaseClass> m_UICollection;
		public ObservableCollection<BaseClass> UICollection
		{
			get { return m_UICollection; }
			set
			{
				if (m_UICollection != value)
				{
					m_UICollection = value;
					NotifyPropertyChanged("UICollection");
				}
			}
		}

		ObservableCollection<BaseClass> m_oldUICollection;
		public ObservableCollection<BaseClass> OldUICollection
		{
			get { return m_oldUICollection; }
			set
			{
				if (m_oldUICollection != value)
				{
					m_oldUICollection = value;
					NotifyPropertyChanged("OldUICollection");
				}
			}
		}

		void CreateUiCollection(int nOffset)
		{
			UICollection = new ObservableCollection<BaseClass>();
			for (int iRow = 0; iRow < 100; iRow++)
			{
				DerivedClass newDerivedClass = new DerivedClass(iRow + nOffset, true);
				UICollection.Add(newDerivedClass);
			}
		}

		private void Button_Click_ClearChildren(object sender, RoutedEventArgs e)
		{
			foreach (DerivedClass derived in UICollection)
			{
				derived.ClearChildren();
			}
		}

		private void Button_Click_FillChildren(object sender, RoutedEventArgs e)
		{
			foreach (DerivedClass derived in UICollection)
			{
				derived.FillChildren();
			}
		}

		//int nSwap = 1;
		//private void Button_Click_SwapCollection(object sender, RoutedEventArgs e)
		//{
		//    OldUICollection = UICollection;
		//    CreateUiCollection(nSwap++);
		//}
		//private void Button_Click_DeleteOldCollection(object sender, RoutedEventArgs e)
		//{
		//    if (OldUICollection != null)
		//    {
		//        foreach (DerivedClass derived in OldUICollection)
		//        {
		//            derived.ClearChildren();
		//        }
		//        OldUICollection.Clear();
		//        OldUICollection = null;
		//    }
		//}


	}


	public class BaseClass
	{
		public BaseClass(int iNdx)
		{
			Property1 = "Property 1 " + iNdx;
		}
		public string Property1 { get; set; }
	}

	public class DerivedClass : BaseClass
	{
		public DerivedClass(int iNdx, bool bAddSubClasses)
			: base(iNdx)
		{
			Ndx = iNdx;
			Property2 = "Property 2 " + Ndx;
			Property3 = "Property 3 " + Ndx;
			Property4 = "Property 4 " + Ndx;
			Property5 = "Property 5 " + Ndx;

			if (bAddSubClasses)
			{
				FillChildren();
			}
		}

		int Ndx { get; set; }
		public string Property2 { get; set; }
		public string Property3 { get; set; }
		public string Property4 { get; set; }
		public string Property5 { get; set; }

		public void ClearChildren()
		{
			SubCollection.Clear();
		}

		public void FillChildren()
		{
			if (SubCollection == null)
			{
				SubCollection = new ObservableCollection<BaseClass>();
			}
			SubCollection.Add(new DerivedClass(((Ndx + 1) * 100) + 1, false));
			SubCollection.Add(new DerivedClass(((Ndx + 1) * 100) + 2, false));
			SubCollection.Add(new DerivedClass(((Ndx + 1) * 100) + 3, false));
			SubCollection.Add(new DerivedClass(((Ndx + 1) * 100) + 4, false));
		}

		public ObservableCollection<BaseClass> SubCollection
		{
			get;
			set;
		}
	}




}
